package Number::Phone::JP::Hyphenate;
{
  $Number::Phone::JP::Hyphenate::VERSION = '0.132131';
}

use strict;
use warnings;
use Number::Phone::JP;

sub hyphenate {
    my ($numeral) = @_;

    my $obj = _num2obj($numeral);

    if ($obj and $obj->is_valid_number and $obj->country_code eq '81') {
        my @parts;
        push @parts, $obj->_prefix;
        my $n = int length($obj->_number) / 2;
        push @parts, split /^\d{$n}\K/, $obj->_number;
        return join('-', @parts);
    }
    
    return;
}

sub _num2obj {
    my ($numeral) = @_;

    if ($numeral =~ m/^\d+$/) {
        for my $prefix (keys %Number::Phone::JP::Table::TEL_TABLE) {
            if ($numeral =~ m/^0$prefix(.*)$/) {
                my $number = $1;
                my $re = $Number::Phone::JP::Table::TEL_TABLE{$prefix};
                if ($number =~ m/$re$/) {
                    return Number::Phone::JP->new("0$prefix", $number);
                }
            }
        }
    }
    elsif ($numeral =~ m/^\+/) {
        $numeral =~ s/[\s-]//g;
        return Number::Phone::JP->new($numeral);
    }
    else {
        return Number::Phone::JP->new($numeral);
    }
}

1;
